@@ -19,7 +19,8 @@ from logging import Logger
 from typing import Any, cast
 
 from .common import IPC_FOLDER, MINIMUM_ADDR_LEN, get_logger
-from .types import ClientInfo, MonitorInfo, PyprError
+from .types import ClientInfo, JSONResponse, MonitorInfo, PyprError, RetensionTimes
+from .utils import CacheData
 
 log: Logger | None = None
 
@@ -42,6 +43,9 @@ async def get_event_stream() -> tuple[asyncio.StreamReader, asyncio.StreamWriter
     return await asyncio.open_unix_connection(EVENTS)
 
 
+# Hyprctl JSON : cached responses {{{
+
+
 def retry_on_reset(func: Callable) -> Callable:
     """Retry on reset wrapper."""
 
@@ -60,42 +64,55 @@ def retry_on_reset(func: Callable) -> Callable:
     return wrapper
 
 
-cached_responses: dict[str, list[Any]] = {
-    # <command name>: [expiration_date, payload, retention_time]
-    "monitors": [0, None, 0.03],
-    # "workspaces": [0, None, 0.1],
-    # "clients": [0, None, 0.02],
+cached_responses: dict[str, CacheData] = {
+    # <command name>: CacheData
+    "monitors": CacheData(retension_time=RetensionTimes.LONG),
+    "workspaces": CacheData(retension_time=RetensionTimes.SHORT),
+    "clients": CacheData(retension_time=RetensionTimes.SHORT),
 }
 
 
-@retry_on_reset
-async def hyprctl_json(command: str, logger: Logger | None = None) -> list[dict[str, Any]] | dict[str, Any]:
-    """Run an IPC command and return the JSON output."""
-    logger = cast(Logger, logger or log)
-    now = time.time()
-    cached = command in cached_responses and cached_responses[command][0] > now
-    if cached:
-        logger.debug("%s (CACHE HIT)", command)
-        return cached_responses[command][1]  # type: ignore
-    logger.debug(command)
+async def _get_response(command: bytes, logger: Logger) -> JSONResponse:
+    """Get response of `command` from the IPC socket."""
     try:
-        ctl_reader, ctl_writer = await asyncio.open_unix_connection(HYPRCTL)
+        reader, writer = await asyncio.open_unix_connection(HYPRCTL)
     except FileNotFoundError as e:
         logger.critical("hyprctl socket not found! is it running ?")
         raise PyprError from e
-    ctl_writer.write(f"-j/{command}".encode())
-    await ctl_writer.drain()
-    resp = await ctl_reader.read()
-    ctl_writer.close()
-    await ctl_writer.wait_closed()
-    ret = json.loads(resp)
+
+    writer.write(command)
+    await writer.drain()
+    reader_data = await reader.read()
+    writer.close()
+    await writer.wait_closed()
+    return json.loads(reader_data)  # type: ignore
+
+
+@retry_on_reset
+async def hyprctl_json(command: str, logger: Logger | None = None) -> JSONResponse:
+    """Run an IPC command and return the JSON output."""
+    logger = cast(Logger, logger or log)
+    now = time.time()
+    cache_data: CacheData | None = cached_responses.get(command)
+    if cache_data and cache_data.expiration_date > now:
+        logger.debug("%s (CACHE HIT)", command)
+        return await cache_data.wait_update()
+
+    logger.debug(command)
+    if cache_data:  # should fill the cache
+        cache_data.set_pending(ref_time=now)
+
+    ret = await _get_response(f"-j/{command}".encode(), logger)
     assert isinstance(ret, list | dict)
-    if command in cached_responses:  # should fill the cache
-        cached_responses[command][0] = now + cached_responses[command][2]
-        cached_responses[command][1] = ret
+    if cache_data:
+        cache_data.set_value(ret)
     return ret
 
 
+# }}}
+
+
+# hyprctl : batched commands {{{
 def _format_command(command_list: list[str] | list[list[str]], default_base_command: str) -> Iterable[str]:
     """Format a list of commands to be sent to Hyprland.
 
@@ -141,12 +158,17 @@ async def hyprctl(command: str | list[str], base_command: str = "dispatch", logg
     resp = await ctl_reader.read(100)
     ctl_writer.close()
     await ctl_writer.wait_closed()
+    # remove "\n" from the response
+    resp = b"".join(resp.split(b"\n"))
     r: bool = resp == b"ok" * nb_cmds
     if not r:
         logger.error("FAILED %s", resp)
     return r
 
 
+# }}}
+
+
 async def get_focused_monitor_props(logger: Logger | None = None, name: str | None = None) -> MonitorInfo:
     """Return focused monitor data if `name` is not defined, else use monitor's name.
 
