@@ -1,2 +1,3 @@
-" built-in plugins "
+"""built-in plugins."""
+
 __all__ = ["interface"]
