@@ -1,4 +1,4 @@
-" Select a client window and move it to the active workspace"
+"""Select a client window and move it to the active workspace."""
 
 from ..adapters.menus import MenuMixin
 from ..common import state
@@ -6,14 +6,14 @@ from .interface import Plugin
 
 
 class Extension(MenuMixin, Plugin):
-    "Shows a menu with shortcuts"
+    """Shows a menu with shortcuts."""
 
     _windows_origins: dict[str, str] = {}
 
     # Commands
 
-    async def run_unfetch_client(self):
-        "Returns a window back to its origin"
+    async def run_unfetch_client(self) -> None:
+        """Return a window back to its origin."""
         addr = state.active_window
         try:
             origin = self._windows_origins[addr]
@@ -22,22 +22,18 @@ class Extension(MenuMixin, Plugin):
         else:
             await self.hyprctl(f"movetoworkspacesilent {origin},address:{addr}")
 
-    async def run_fetch_client_menu(self):
-        "Select a client window and move it to the active workspace"
+    async def run_fetch_client_menu(self) -> None:
+        """Select a client window and move it to the active workspace."""
         await self.ensure_menu_configured()
 
         clients = await self.get_clients(workspace_bl=state.active_workspace)
 
         separator = self.config.get("separator", "|")
 
-        choice = await self.menu.run(
-            [f"{i+1} {separator} {c['title']}" for i, c in enumerate(clients)]
-        )
+        choice = await self.menu.run([f"{i + 1} {separator} {c['title']}" for i, c in enumerate(clients)])
 
         if choice:
             num = int(choice.split(None, 1)[0]) - 1
             addr = clients[num]["address"]
             self._windows_origins[addr] = clients[num]["workspace"]["name"]
-            await self.hyprctl(
-                f"movetoworkspace {state.active_workspace},address:{addr}"
-            )
+            await self.hyprctl(f"movetoworkspace {state.active_workspace},address:{addr}")
