@@ -97,10 +97,10 @@ class Extension(CastBoolMixin, Plugin):
         """Loads the configuration and apply the tag style."""
         if not self.config.get("style"):
             return
-        await self.hyprctl("windowrulev2 unset, tag:layout_center")
+        await self.hyprctl("windowrulev2 unset, tag:layout_center", "keyword")
         commands = [f"windowrulev2 {rule}, tag:layout_center" for rule in self.config.get("style", [])]
         if commands:
-            await self.hyprctl(commands)
+            await self.hyprctl(commands, "keyword")
 
     # Utils
 
@@ -167,7 +167,7 @@ class Extension(CastBoolMixin, Plugin):
     async def _run_changefocus(self, direction: int, default_override: str | None = None) -> None:
         """Change the focus in the given direction (-1 or 1)."""
         if self.enabled:
-            clients = await self.get_clients()
+            clients = [cli for cli in await self.get_clients() if not cli.get("floating") or cli["address"] == self.main_window_addr]
             if await self._sanity_check(clients):
                 addresses = [c["address"] for c in clients]
                 try:
