@@ -105,12 +105,19 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         """Reload the plugin."""
         self._clear_mon_by_pat_cache()
         monitors = await self.hyprctl_json("monitors")
-        if self.cast_bool(self.config.get("startup_relayout"), True):
-            await self.run_relayout(monitors)
 
         for mon in state.monitors:
             await self._hotplug_command(name=mon, monitors=monitors)
 
+        if self.cast_bool(self.config.get("startup_relayout"), True):
+            # run relayout after 1second without blocking
+
+            async def _delayed_relayout() -> None:
+                await asyncio.sleep(1)
+                await self.run_relayout(monitors)
+
+            await asyncio.create_task(_delayed_relayout())
+
     def _build_monitor_command(self, monitor: MonitorInfo, config: dict[str, dict[str, Any]], every_monitor: dict[str, MonitorInfo]) -> str:
         """Build the monitor command."""
         name = monitor["name"]
@@ -147,14 +154,12 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         graph = build_graph(cleaned_config)
         need_change = self._update_positions(monitors, graph, cleaned_config)
         every_monitor = {v["name"]: v for v in await self.hyprctl_json("monitors all")}
-        if need_change:
-            if self.cast_bool(self.config.get("trim_offset"), True):
-                trim_offset(monitors)
+        if self.cast_bool(self.config.get("trim_offset"), True):
+            trim_offset(monitors)
 
-            for monitor in sorted(monitors, key=lambda x: x["x"] + x["y"]):
-                await self.hyprctl(self._build_monitor_command(monitor, cleaned_config, every_monitor), "keyword")
-            return True
-        return False
+        for monitor in sorted(monitors, key=lambda x: x["x"] + x["y"]):
+            await self.hyprctl(self._build_monitor_command(monitor, cleaned_config, every_monitor), "keyword")
+        return need_change
 
     # Event handlers
 
